@@ -2,6 +2,7 @@ from pathlib import Path
 
 import git
 from git.exc import GitCommandError
+
 from patchwork.common.client.scm import (
     GithubClient,
     GitlabClient,
@@ -16,30 +17,33 @@ class CreatePR(Step):
     required_keys = {"target_branch"}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
-        self.scm_client = None
-        if "github_api_key" in inputs.keys():
-            self.scm_client = GithubClient(inputs["github_api_key"])
-        elif "gitlab_api_key" in inputs.keys():
-            self.scm_client = GitlabClient(inputs["gitlab_api_key"])
-        else:
-            logger.warning(f'Missing required input data: "github_api_key" or "gitlab_api_key",'
-                           f' PR creation will be disabled.')
+        self.enabled = not bool(inputs.get("disable_pr", False))
+        if self.enabled:
+            self.scm_client = None
+            if "github_api_key" in inputs.keys():
+                self.scm_client = GithubClient(inputs["github_api_key"])
+            elif "gitlab_api_key" in inputs.keys():
+                self.scm_client = GitlabClient(inputs["gitlab_api_key"])
+            else:
+                logger.warning(
+                    f'Missing required input data: "github_api_key" or "gitlab_api_key",'
+                    f" PR creation will be disabled."
+                )
+                self.enabled = False
 
-        if self.scm_client is not None:
+        if self.enabled:
             if "scm_url" in inputs.keys():
                 self.scm_client.set_url(inputs["scm_url"])
 
             if not self.scm_client.test():
-                raise ValueError(f"{self.scm_client.__class__.__name__} token test failed.")
-
-            self.enabled = not bool(inputs.get("disable_pr", False))
-        else:
-            self.enabled = False
+                logger.warning(
+                    f"{self.scm_client.__class__.__name__} token test failed. " f"PR creation will be disabled."
+                )
+                self.enabled = False
 
         self.pr_body = inputs.get("pr_body", "")
         self.title = inputs.get("pr_title", "Patchwork PR")
@@ -56,10 +60,6 @@ class CreatePR(Step):
     def run(self) -> dict:
         repo = git.Repo(Path.cwd(), search_parent_directories=True)
 
-        if not self.enabled:
-            logger.warning(f"PR creation is disabled. Skipping PR creation.")
-            return dict()
-
         original_remote_name = "origin"
         push_args = ["--set-upstream", original_remote_name, self.target_branch]
         if self.force:
@@ -68,6 +68,10 @@ class CreatePR(Step):
         push(repo, push_args)
         logger.debug(f"Pushed to {original_remote_name}/{self.target_branch}")
 
+        if not self.enabled:
+            logger.warning(f"PR creation is disabled. Skipping PR creation.")
+            return dict()
+
         logger.info(f"Creating PR from {self.base_branch} to {self.target_branch}")
         original_remote_url = repo.remotes[original_remote_name].url
         repo_slug = get_slug_from_remote_url(original_remote_url)
@@ -82,7 +86,6 @@ class CreatePR(Step):
         )
 
         logger.info(f"[green]PR created at [link={url}]{url}[/link][/]", extra={"markup": True})
-        logger.info(f"Run completed {self.__class__.__name__}")
         return {"pr_url": url}
 
 
@@ -105,7 +108,8 @@ def create_pr(
     scm_client: ScmPlatformClientProtocol,
     force: bool = False,
 ):
-    pr = scm_client.find_pr(repo_slug, base_branch_name, target_branch_name)
+    prs = scm_client.find_prs(repo_slug, original_branch=base_branch_name, feature_branch=target_branch_name)
+    pr = next(iter(prs), None)
     if pr is None:
         pr = scm_client.create_pr(
             repo_slug,
