@@ -1,5 +1,4 @@
 import json
-import tempfile
 
 from patchwork.common.utils.utils import exclude_none_dict
 from patchwork.step import Step
@@ -32,29 +31,33 @@ class SimplifiedLLM(Step):
         self.inputs = inputs
 
     def run(self) -> dict:
-        with tempfile.NamedTemporaryFile("w") as fp:
-            prompt_id = "prompt_id"
-            prompts = [dict(role="user", content=self.user)]
-            if self.system:
-                prompts.insert(0, dict(role="system", content=self.system))
-            json.dump([dict(id=prompt_id, prompts=prompts)], fp)
-            fp.flush()
-            prepare_prompt_inputs = dict(
-                prompt_template_file=fp.name,
-                prompt_id=prompt_id,
-                prompt_values=self.prompt_values,
-            )
-            prepare_prompt_outputs = PreparePrompt(prepare_prompt_inputs).run()
+        prompts = [dict(role="user", content=self.user)]
+        if self.system:
+            prompts.insert(0, dict(role="system", content=self.system))
+        prepare_prompt_inputs = dict(
+            prompt_template=prompts,
+            prompt_values=self.prompt_values,
+        )
+        prepare_prompt_outputs = PreparePrompt(prepare_prompt_inputs).run()
 
-        call_llm_inputs = dict(
-            model_response_format=dict(type="json_object" if self.is_json_mode else "text"),
-            prompts=prepare_prompt_outputs.get("prompts"),
+        model_keys = [key for key in self.inputs.keys() if key.startswith("model_")]
+        call_llm_inputs = {
+            "prompts": prepare_prompt_outputs.get("prompts"),
             **{
                 key: self.inputs[key]
-                for key in ["model", "openai_api_key", "patched_api_key", "google_api_key", "max_llm_calls"]
+                for key in [
+                    "model",
+                    "openai_api_key",
+                    "patched_api_key",
+                    "google_api_key",
+                    "anthropic_api_key",
+                    "max_llm_calls",
+                    *model_keys,
+                ]
                 if self.inputs.get(key) is not None
             },
-        )
+            "model_response_format": dict(type="json_object" if self.is_json_mode else "text"),
+        }
         call_llm_outputs = CallLLM(call_llm_inputs).run()
 
         if self.is_json_mode:
